==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.md <==
# ServiceTimeSeriesInsightsAccessPolicies


```text
azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies
```

```text
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')
```



| Illustration | ServiceTimeSeriesInsightsAccessPolicies | ServiceTimeSeriesInsightsAccessPoliciesCard | ServiceTimeSeriesInsightsAccessPoliciesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.png) | ![illustration for ServiceTimeSeriesInsightsAccessPolicies](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.Local.png) | ![illustration for ServiceTimeSeriesInsightsAccessPoliciesCard](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPoliciesCard.Local.png) | ![illustration for ServiceTimeSeriesInsightsAccessPoliciesGroup](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPoliciesGroup.Local.png) |




## ServiceTimeSeriesInsightsAccessPolicies

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPolicies
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPolicies('ServiceTimeSeriesInsightsAccessPolicies', 'Service Time Series Insights Access Policies', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPolicies
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPolicies('ServiceTimeSeriesInsightsAccessPolicies', 'Service Time Series Insights Access Policies', 'an optional tech label')
@enduml
```

## ServiceTimeSeriesInsightsAccessPoliciesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesCard
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesCard('ServiceTimeSeriesInsightsAccessPoliciesCard', 'Service Time Series Insights Access Policies Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesCard
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesCard('ServiceTimeSeriesInsightsAccessPoliciesCard', 'Service Time Series Insights Access Policies Card', 'an optional description')
@enduml
```

## ServiceTimeSeriesInsightsAccessPoliciesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesGroup
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesGroup('ServiceTimeSeriesInsightsAccessPoliciesGroup', 'Service Time Series Insights Access Policies Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesGroup
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesGroup('ServiceTimeSeriesInsightsAccessPoliciesGroup', 'Service Time Series Insights Access Policies Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.md <==
# ServiceTimeSeriesInsightsAccessPolicies


```text
azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies
```

```text
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')
```



| Illustration | ServiceTimeSeriesInsightsAccessPolicies | ServiceTimeSeriesInsightsAccessPoliciesCard | ServiceTimeSeriesInsightsAccessPoliciesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.png) | ![illustration for ServiceTimeSeriesInsightsAccessPolicies](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies.Local.png) | ![illustration for ServiceTimeSeriesInsightsAccessPoliciesCard](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPoliciesCard.Local.png) | ![illustration for ServiceTimeSeriesInsightsAccessPoliciesGroup](../../../azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPoliciesGroup.Local.png) |




## ServiceTimeSeriesInsightsAccessPolicies

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPolicies
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPolicies('ServiceTimeSeriesInsightsAccessPolicies', 'Service Time Series Insights Access Policies', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPolicies
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPolicies('ServiceTimeSeriesInsightsAccessPolicies', 'Service Time Series Insights Access Policies', 'an optional tech label')
@enduml
```

## ServiceTimeSeriesInsightsAccessPoliciesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesCard
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesCard('ServiceTimeSeriesInsightsAccessPoliciesCard', 'Service Time Series Insights Access Policies Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesCard
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesCard('ServiceTimeSeriesInsightsAccessPoliciesCard', 'Service Time Series Insights Access Policies Card', 'an optional description')
@enduml
```

## ServiceTimeSeriesInsightsAccessPoliciesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesGroup
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesGroup('ServiceTimeSeriesInsightsAccessPoliciesGroup', 'Service Time Series Insights Access Policies Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceTimeSeriesInsightsAccessPoliciesGroup
include('azure-4/Item/InternetOfThings/ServiceTimeSeriesInsightsAccessPolicies')

' renders the element
ServiceTimeSeriesInsightsAccessPoliciesGroup('ServiceTimeSeriesInsightsAccessPoliciesGroup', 'Service Time Series Insights Access Policies Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
